@@ -4,6 +4,7 @@
 ## Description: collocation db, top-level
 
 package DiaColloDB;
+require 5.10.0; ##-- for // operator
 use DiaColloDB::Client;
 use DiaColloDB::Logger;
 use DiaColloDB::EnumFile;
@@ -33,7 +34,7 @@ use strict;
 ##==============================================================================
 ## Globals & Constants
 
-our $VERSION = "0.07.010";
+our $VERSION = "0.07.014";
 our @ISA = qw(DiaColloDB::Client);
 
 ## $PGOOD_DEFAULT
@@ -1771,7 +1772,7 @@ sub profile {
   $coldb->vlog($coldb->{logRequest},
 	       "profile("
 	       .join(', ',
-		     map {"$_->[0]='".quotemeta($_->[1]//'')}
+		     map {"$_->[0]='".quotemeta($_->[1]//'')."'"}
 		     ([rel=>$rel],
 		      [query=>$opts{query}],
 		      [groupby=>UNIVERSAL::isa($opts{groupby},'ARRAY') ? join(',', @{$opts{groupby}}) : $opts{groupby}],
